@@ -7,8 +7,6 @@ var fs = require('fs');
 var config = require('./config');
 var http = require('http');
 var https = require('https');
-http.globalAgent.maxSockets = config.maxSockets;
-https.globalAgent.maxSockets = config.maxSockets;
 var logger = require('./lib/logger');
 var Promise = require('bluebird');
 var initialization = require('./lib/serverInitialization');
