@@ -6,29 +6,17 @@ var express = require('express');
 var _ = require('lodash');
 var fs = require('fs');
 var url = require('url');
-var target = url.parse(config.elasticsearch);
 var join = require('path').join;
 var logger = require('../lib/logger');
 var validateRequest = require('../lib/validateRequest');
 
-
-// If the target is backed by an SSL and a CA is provided via the config
-// then we need to inject the CA
-var customCA;
-if (/^https/.test(target.protocol) && config.kibana.ca) {
-  customCA = fs.readFileSync(config.kibana.ca, 'utf8');
-}
-// Add client certificate and key if required by elasticsearch
-var clientCrt;
-var clientKey;
-if (/^https/.test(target.protocol) && config.kibana.kibana_elasticsearch_client_crt && config.kibana.kibana_elasticsearch_client_key) {
-  clientCrt = fs.readFileSync(config.kibana.kibana_elasticsearch_client_crt, 'utf8');
-  clientKey = fs.readFileSync(config.kibana.kibana_elasticsearch_client_key, 'utf8');
-}
-
 // Create the router
 var router = module.exports = express.Router();
 
+// allow overriding agent for testing purposes
+router.proxyTarget = url.parse(config.elasticsearch);
+router.proxyAgent = require('../lib/proxyAgent').buildForProtocol(router.proxyTarget.protocol);
+
 // We need to capture the raw body before moving on
 router.use(function (req, res, next) {
   var chunks = [];
@@ -59,7 +47,7 @@ function getPort(req) {
 
 // Create the proxy middleware
 router.use(function (req, res, next) {
-  var uri = _.defaults({}, target);
+  var uri = _.defaults({}, router.proxyTarget);
 
   // Add a slash to the end of the URL so resolve doesn't remove it.
   var path = (/\/$/.test(uri.path)) ? uri.path : uri.path + '/';
@@ -71,6 +59,7 @@ router.use(function (req, res, next) {
   }
 
   var options = {
+    agent: router.proxyAgent,
     url: config.elasticsearch + path,
     method: req.method,
     headers: _.defaults({}, req.headers),
@@ -82,20 +71,6 @@ router.use(function (req, res, next) {
   options.headers['x-forward-port'] = getPort(req);
   options.headers['x-forward-proto'] = req.connection.pair ? 'https' : 'http';
 
-  // If the server has a custom CA we need to add it to the agent options
-  if (customCA) {
-    options.agentOptions = { ca: [customCA] };
-  }
-
-  // Add client key and certificate for elasticsearch if needed.
-  if (clientCrt && clientKey) {
-    if (!options.agentOptions) {
-      options.agentOptions = {};
-    }
-    options.agentOptions.cert = clientCrt;
-    options.agentOptions.key = clientKey;
-  }
-
   // Only send the body if it's a PATCH, PUT, or POST
   if (req.rawBody) {
     options.headers['content-length'] = req.rawBody.length;
@@ -108,7 +83,7 @@ router.use(function (req, res, next) {
   // host header to the target host header. I don't quite understand the value
   // of this... but it's a feature we had before so I guess we are keeping it.
   if (config.kibana.elasticsearch_preserve_host) {
-    options.headers.host = target.host;
+    options.headers.host = router.proxyTarget.host;
   }
 
   // Create the request and pipe the response
